==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/mediaplayer/translations/mediaplayer_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>Syntax: %t - song title,
%a - album, %r - artist, %f - file name,
%l - song length (MM:SS), %c - current song position (MM:SS),
%p - percents of played song, %n - player name, %v - player version
</source>
        <translation>Sintaxis: %t - título de la canción,
%a - álbum, %r - artista, %f - nombre de archivo,
%l - duración de la canción (MM:SS), %c - actual posición de la canción (MM:SS),
%p - porcentaje de la canción reproducida, %n - nombre del reproductor, %v - versión del reproductor
</translation>
    </message>
    <message>
        <source>Pseudo-OSD for MediaPlayer</source>
        <translation>Seudo-OSD para el Reproductor Multimedia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>MediaPlayer statuses in description</source>
        <translation>Estados del reproductor multimedia en la descripción</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Sustituir</translation>
    </message>
    <message>
        <source>MediaPlayer description format</source>
        <translation>Formato de la descripción del reproductor multimedia</translation>
    </message>
    <message>
        <source>Here specify format which will replace &apos;#{player}&apos; tag when you will use it in description while setting status.</source>
        <translation>Aquí especificar el formato que reemplazará la etiqueta &apos;#{reproductor}&apos; cuando lo usará en la descripción mientras establece el estado.</translation>
    </message>
    <message>
        <source>Signatures to cut</source>
        <translation>Firmas para cortar</translation>
    </message>
    <message>
        <source>Crap to cut</source>
        <translation>Elemento a eliminar</translation>
    </message>
    <message>
        <source>Enable pseudo-OSD</source>
        <translation>Habilitar seudo-OSD</translation>
    </message>
    <message>
        <source>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</source>
        <translation>Habilita seudo-OSD realizado por las sugerencias de Kadu. Muestra actualmente el título reproducido en la sugerencia.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer keyboard shortcuts in chat window</source>
        <translation>Habilitar accesos rápidos del reproductor multimedia en la ventana de conversación</translation>
    </message>
    <message>
        <source>Put statuses switch to dock menu</source>
        <translation>Colocar el botón de estados anclado al menú</translation>
    </message>
    <message>
        <source>Enable this to put MediaPlayer statuses switch into docked icon menu.</source>
        <translation>Habilitar esto para colocar el botón de estados del reproductor multimedia anclado al menú de iconos.</translation>
    </message>
    <message>
        <source>Signature Cutting</source>
        <translation>Corte de Firma</translation>
    </message>
    <message>
        <source>Other Settings</source>
        <translation>Otros ajustes</translation>
    </message>
    <message>
        <source>With this option enabled you&apos;ll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Control+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Con esta opción habilitada, usted será capaz de controlar
su reproductor multimedia en la ventana de conversación mediante los accesos rápidos:
Control+ Enter/Backspace/Left/Right/Up/Down.</translation>
    </message>
    <message>
        <source>With this option enabled you&apos;ll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Win+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Con esta opción habilitada, usted será capaz de controlar
su reproductor multimedia en la ventana de conversación mediante los accesos rápidos:
Win+ Enter/Backspace/Left/Right/Up/Down.</translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation>Agregar en el frente</translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation>Agregar en la parte posterior</translation>
    </message>
    <message>
        <source>Replace &apos;#{player}&apos; Tag</source>
        <translation>Reemplazar la etiqueta &apos;#{reproductor}&apos;</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Extras</translation>
    </message>
    <message>
        <source>Media Player</source>
        <translation>Reproductor Multimedia</translation>
    </message>
    <message>
        <source>MediaPlayer message format in chat window</source>
        <translation>Formato de mensaje del reproductor multimedia en la ventana de conversación</translation>
    </message>
    <message>
        <source>Enable signature cutting</source>
        <translation>Habilitar el corte de firma</translation>
    </message>
    <message>
        <source>Enable removing non-essential stuff from audio file titles</source>
        <translation>Habilitar la eliminación de material no esencial de los títulos de los archivos de audio</translation>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <source>Put formated string</source>
        <translation>Colocar cadena con formato</translation>
    </message>
    <message>
        <source>Put song title</source>
        <translation>Colocar el título de la canción</translation>
    </message>
    <message>
        <source>Put song file name</source>
        <translation>Colocar el nombre del archivo de la canción</translation>
    </message>
    <message>
        <source>Send all playlist titles</source>
        <translation>Enviar todos los títulos de la lista de reproducción</translation>
    </message>
    <message>
        <source>Send all playlist files</source>
        <translation>Enviar todos los archivos de la lista de reproducción</translation>
    </message>
    <message>
        <source>Enable MediaPlayer statuses</source>
        <translation>Habilitar los estados del reproductor multimedia</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>Reproductor multimedia</translation>
    </message>
    <message>
        <source>%1 isn&apos;t running!</source>
        <translation>¡%1 no se está ejecutando!</translation>
    </message>
    <message>
        <source>You&apos;re trying to send %1 entries of %2 playlist.&lt;br&gt;It will be split and sent in few messages&lt;br&gt;Are you sure to do that?</source>
        <translation>Usted está tratando de enviar %1 entradas de %2 listas de reproducción.&lt;br&gt;Se dividirá y enviara en pocos mensajes&lt;br&gt;¿Esta seguro de hacer eso?</translation>
    </message>
    <message>
        <source>Playback stopped.</source>
        <translation>La reproducción se detuvo.</translation>
    </message>
    <message>
        <source>Player turned off.</source>
        <translation>Reproductor apagado.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer Statuses</source>
        <translation>Habilitar los Estados del Reproductor Multimedia</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Previous Track</source>
        <translation>Anterior pista</translation>
    </message>
    <message>
        <source>Next Track</source>
        <translation>Siguiente pista</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Subir Volumen</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Bajar Volumen</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>More than 1/10 of titles you&apos;re trying to send are empty.&lt;br&gt;Perhaps %1 hasn&apos;t read all titles yet, give its some more time.&lt;br&gt;Do you want to send playlist anyway?</source>
        <translation>Más de un 1/10 de los títulos que usted está tratando de enviar están vacíos.&lt;br&gt;Tal vez %1 todavía no ha leído todos los títulos, dele un poco mas de tiempo.&lt;br&gt;¿Quiere enviar la lista de reproducción de todos modos?</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Player isn&apos;t running!</source>
        <translation>¡El reproductor no se está ejecutando!</translation>
    </message>
    <message>
        <source>Send anyway</source>
        <translation>Enviar de todos modos</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/mediaplayer/translations/mediaplayer_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Syntax: %t - song title,
%a - album, %r - artist, %f - file name,
%l - song length (MM:SS), %c - current song position (MM:SS),
%p - percents of played song, %n - player name, %v - player version
</source>
        <translation>Sintaxis: %t - título de la canción,
%a - álbum, %r - artista, %f - nombre de archivo,
%l - duración de la canción (MM:SS), %c - actual posición de la canción (MM:SS),
%p - porcentaje de la canción reproducida, %n - nombre del reproductor, %v - versión del reproductor
</translation>
    </message>
    <message>
        <source>Pseudo-OSD for MediaPlayer</source>
        <translation>Seudo-OSD para el Reproductor Multimedia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>MediaPlayer statuses in description</source>
        <translation>Estados del reproductor multimedia en la descripción</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Sustituir</translation>
    </message>
    <message>
        <source>MediaPlayer description format</source>
        <translation>Formato de la descripción del reproductor multimedia</translation>
    </message>
    <message>
        <source>Here specify format which will replace &apos;#{player}&apos; tag when you will use it in description while setting status.</source>
        <translation>Aquí especificar el formato que reemplazará la etiqueta &apos;#{reproductor}&apos; cuando lo usará en la descripción mientras establece el estado.</translation>
    </message>
    <message>
        <source>Signatures to cut</source>
        <translation>Firmas para cortar</translation>
    </message>
    <message>
        <source>Crap to cut</source>
        <translation>Elemento a eliminar</translation>
    </message>
    <message>
        <source>Enable pseudo-OSD</source>
        <translation>Habilitar seudo-OSD</translation>
    </message>
    <message>
        <source>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</source>
        <translation>Habilita seudo-OSD realizado por las sugerencias de Kadu. Muestra actualmente el título reproducido en la sugerencia.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer keyboard shortcuts in chat window</source>
        <translation>Habilitar accesos rápidos del reproductor multimedia en la ventana de conversación</translation>
    </message>
    <message>
        <source>Put statuses switch to dock menu</source>
        <translation>Colocar el botón de estados anclado al menú</translation>
    </message>
    <message>
        <source>Enable this to put MediaPlayer statuses switch into docked icon menu.</source>
        <translation>Habilitar esto para colocar el botón de estados del reproductor multimedia anclado al menú de iconos.</translation>
    </message>
    <message>
        <source>Signature Cutting</source>
        <translation>Corte de Firma</translation>
    </message>
    <message>
        <source>Other Settings</source>
        <translation>Otros ajustes</translation>
    </message>
    <message>
        <source>With this option enabled you'll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Win+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Con esta opción habilitada, usted será capaz de controlar
su reproductor multimedia en la ventana de conversación mediante los accesos rápidos:
Win+ Enter/Backspace/Left/Right/Up/Down.</translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation>Agregar en el frente</translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation>Agregar en la parte posterior</translation>
    </message>
    <message>
        <source>Replace &apos;#{player}&apos; Tag</source>
        <translation>Reemplazar la etiqueta &apos;#{reproductor}&apos;</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Extras</translation>
    </message>
    <message>
        <source>Media Player</source>
        <translation>Reproductor Multimedia</translation>
    </message>
    <message>
        <source>MediaPlayer message format in chat window</source>
        <translation>Formato de mensaje del reproductor multimedia en la ventana de conversación</translation>
    </message>
    <message>
        <source>Enable signature cutting</source>
        <translation>Habilitar el corte de firma</translation>
    </message>
    <message>
        <source>Enable removing non-essential stuff from audio file titles</source>
        <translation>Habilitar la eliminación de material no esencial de los títulos de los archivos de audio</translation>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <source>Put formated string</source>
        <translation>Colocar cadena con formato</translation>
    </message>
    <message>
        <source>Put song title</source>
        <translation>Colocar el título de la canción</translation>
    </message>
    <message>
        <source>Put song file name</source>
        <translation>Colocar el nombre del archivo de la canción</translation>
    </message>
    <message>
        <source>Send all playlist titles</source>
        <translation>Enviar todos los títulos de la lista de reproducción</translation>
    </message>
    <message>
        <source>Send all playlist files</source>
        <translation>Enviar todos los archivos de la lista de reproducción</translation>
    </message>
    <message>
        <source>Enable MediaPlayer statuses</source>
        <translation>Habilitar los estados del reproductor multimedia</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>Reproductor multimedia</translation>
    </message>
    <message>
        <source>%1 isn&apos;t running!</source>
        <translation>¡%1 no se está ejecutando!</translation>
    </message>
    <message>
        <source>You&apos;re trying to send %1 entries of %2 playlist.&lt;br&gt;It will be split and sent in few messages&lt;br&gt;Are you sure to do that?</source>
        <translation>Usted está tratando de enviar %1 entradas de %2 listas de reproducción.&lt;br&gt;Se dividirá y enviara en pocos mensajes&lt;br&gt;¿Esta seguro de hacer eso?</translation>
    </message>
    <message>
        <source>Playback stopped.</source>
        <translation>La reproducción se detuvo.</translation>
    </message>
    <message>
        <source>Player turned off.</source>
        <translation>Reproductor apagado.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer Statuses</source>
        <translation>Habilitar los Estados del Reproductor Multimedia</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Previous Track</source>
        <translation>Anterior pista</translation>
    </message>
    <message>
        <source>Next Track</source>
        <translation>Siguiente pista</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Subir Volumen</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Bajar Volumen</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>More than 1/10 of titles you&apos;re trying to send are empty.&lt;br&gt;Perhaps %1 hasn&apos;t read all titles yet, give its some more time.&lt;br&gt;Do you want to send playlist anyway?</source>
        <translation>Más de un 1/10 de los títulos que usted está tratando de enviar están vacíos.&lt;br&gt;Tal vez %1 todavía no ha leído todos los títulos, dele un poco mas de tiempo.&lt;br&gt;¿Quiere enviar la lista de reproducción de todos modos?</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Player isn&apos;t running!</source>
        <translation>¡El reproductor no se está ejecutando!</translation>
    </message>
    <message>
        <source>Send anyway</source>
        <translation>Enviar de todos modos</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Enviar</translation>
    </message>
</context>
</TS>
